@@ -31,12 +31,7 @@
 #include <KToolBar>
 #include <KToggleAction>
 
-#include <knewstuff_version.h>
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
-#include <KNS3/QtQuickDialogWrapper>
-#else
 #include <KNSWidgets/Dialog>
-#endif
 //Project includes
 #include "ui_fontsdlg.h"
 #include "timer.h"
@@ -249,22 +244,10 @@ void KLettres::loadSettings()
 
 void KLettres::slotDownloadNewStuff()
 {
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KNS3::QtQuickDialogWrapper *dialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("klettres.knsrc"), this);
-#else
     KNSWidgets::Dialog *dialog = new KNSWidgets::Dialog(QStringLiteral("khangman.knsrc"), this);
-#endif
     dialog->open();
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    connect(dialog, &KNS3::QtQuickDialogWrapper::closed, this, [this, dialog] {
-#else
     connect(dialog, &KNSWidgets::Dialog::finished, this, [this, dialog] {
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        const QList<KNSCore::EntryInternal> entries = dialog->changedEntries();
-#else
         const QList<KNSCore::Entry> entries = dialog->changedEntries();
-#endif
         if (!entries.isEmpty()) {
             //look for languages dirs installed
             QStringList languages = LangUtils::getLanguages();
@@ -408,9 +391,6 @@ void KLettres::loadLangToolBar()
         QFile openFileStream(myFile.fileName());
         openFileStream.open(QIODevice::ReadOnly);
         QTextStream readFileStr(&openFileStream);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        readFileStr.setCodec("UTF-8");
-#endif
         //allData contains all the words from the file
         allData = readFileStr.readAll().split(QLatin1Char('\n'));
         openFileStream.close();
