@@ -11,9 +11,6 @@
 #include <QCommandLineParser>
 
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KCrash>
 #include <KAboutData>
 #include "klettres.h"
@@ -22,20 +19,7 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-    KLocalizedString::setApplicationDomain("klettres");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QStringList configFiles;
-    QStringList rcFiles;
-    configFiles << QStringLiteral("klettresrc");
-    rcFiles << QStringLiteral("klettresui.rc");
-    Kdelibs4ConfigMigrator migrator(QStringLiteral("klettres"));
-    migrator.setConfigFiles(configFiles);
-    migrator.setUiFiles(rcFiles);
-    migrator.migrate();
-#endif
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("klettres"));
 
     KAboutData about(QStringLiteral("klettres"), i18n("KLettres"), QStringLiteral(KLETTRES_VERSION_STRING), i18n("KLettres helps a very young child or an adult learning \n"
                                                                                                                  "a new language by associating sounds and \n"
